@@ -142,7 +142,7 @@ void FolderModel::loadPendingThumbnails() {
     hasPendingThumbnailHandler_ = false;
     for(auto& item: thumbnailData_) {
         if(!item.pendingThumbnails_.empty()) {
-            auto job = new Fm::ThumbnailJob(std::move(item.pendingThumbnails_), item.size_);
+            auto job = new Fm::ThumbnailJob(std::move(item.pendingThumbnails_), item.size_, folder_ != nullptr && folder_->isValid() && folder_->info()->isRemoteDirectory());
             pendingThumbnailJobs_.push_back(job);
             job->setAutoDelete(true);
             connect(job, &Fm::ThumbnailJob::thumbnailLoaded, this, &FolderModel::onThumbnailLoaded, Qt::BlockingQueuedConnection);
