@@ -218,7 +218,7 @@
     <message>
         <location filename="../file-props.ui" line="241"/>
         <source>Last modified:</source>
-        <translation type="unfinished"></translation>
+        <translation>पिछला संपादन:</translation>
     </message>
     <message>
         <location filename="../file-props.ui" line="106"/>
@@ -1003,12 +1003,12 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="486"/>
+        <location filename="../core/filetransferjob.cpp" line="492"/>
         <source>Cannot copy a directory into itself!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="537"/>
+        <location filename="../core/filetransferjob.cpp" line="543"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1141,7 +1141,7 @@ Do you want to delete them instead?</source>
     <message>
         <location filename="../foldermodel.cpp" line="319"/>
         <source>Last modified:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">पिछला संपादन:</translation>
     </message>
     <message>
         <location filename="../foldermodel.cpp" line="320"/>
@@ -1318,7 +1318,7 @@ Do you want to delete them instead?</source>
     </message>
     <message>
         <location filename="../placesview.cpp" line="600"/>
-        <location filename="../placesview.cpp" line="662"/>
+        <location filename="../placesview.cpp" line="667"/>
         <source>Hide</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1344,7 +1344,7 @@ Do you want to delete them instead?</source>
     </message>
     <message>
         <location filename="../placesview.cpp" line="643"/>
-        <location filename="../placesview.cpp" line="676"/>
+        <location filename="../placesview.cpp" line="681"/>
         <source>Unmount</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1359,7 +1359,12 @@ Do you want to delete them instead?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="688"/>
+        <location filename="../placesview.cpp" line="658"/>
+        <source>Safely Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="693"/>
         <source>Show All Entries</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1486,7 +1491,7 @@ Modified: %2</source>
     <message>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="674"/>
-        <location filename="../mountoperation.cpp" line="297"/>
+        <location filename="../mountoperation.cpp" line="315"/>
         <location filename="../utilities.cpp" line="154"/>
         <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
