@@ -1011,12 +1011,12 @@ Ar norite vietoj to, juos ištrinti?</translation>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="486"/>
+        <location filename="../core/filetransferjob.cpp" line="492"/>
         <source>Cannot copy a directory into itself!</source>
         <translation>Negalima kopijuoti katalogą į jį patį!</translation>
     </message>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="537"/>
+        <location filename="../core/filetransferjob.cpp" line="543"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation>Nepavyksta sukurti nuorodą ne savoje failų sistemoje</translation>
     </message>
@@ -1326,7 +1326,7 @@ Ar norite vietoj to, juos ištrinti?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="600"/>
-        <location filename="../placesview.cpp" line="662"/>
+        <location filename="../placesview.cpp" line="667"/>
         <source>Hide</source>
         <translation>Slėpti</translation>
     </message>
@@ -1352,7 +1352,7 @@ Ar norite vietoj to, juos ištrinti?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="643"/>
-        <location filename="../placesview.cpp" line="676"/>
+        <location filename="../placesview.cpp" line="681"/>
         <source>Unmount</source>
         <translation>Atjungti</translation>
     </message>
@@ -1367,7 +1367,12 @@ Ar norite vietoj to, juos ištrinti?</translation>
         <translation>Išstumti</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="688"/>
+        <location filename="../placesview.cpp" line="658"/>
+        <source>Safely Remove</source>
+        <translation>Saugiai pašalinti</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="693"/>
         <source>Show All Entries</source>
         <translation>Rodyti visus įrašus</translation>
     </message>
@@ -1497,7 +1502,7 @@ Pakeista: %2</translation>
     <message>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="674"/>
-        <location filename="../mountoperation.cpp" line="297"/>
+        <location filename="../mountoperation.cpp" line="315"/>
         <location filename="../utilities.cpp" line="154"/>
         <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
