@@ -1007,12 +1007,12 @@ Wilt u ze in plaats daarvan permanent verwijderen?</translation>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="486"/>
+        <location filename="../core/filetransferjob.cpp" line="492"/>
         <source>Cannot copy a directory into itself!</source>
         <translation>Kan map niet naar zichzelf kopiëren!</translation>
     </message>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="537"/>
+        <location filename="../core/filetransferjob.cpp" line="543"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation>Kan geen koppeling aanmaken op een niet-eigen bestandssysteem</translation>
     </message>
@@ -1322,7 +1322,7 @@ Wilt u ze in plaats daarvan permanent verwijderen?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="600"/>
-        <location filename="../placesview.cpp" line="662"/>
+        <location filename="../placesview.cpp" line="667"/>
         <source>Hide</source>
         <translation>Verbergen</translation>
     </message>
@@ -1348,7 +1348,7 @@ Wilt u ze in plaats daarvan permanent verwijderen?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="643"/>
-        <location filename="../placesview.cpp" line="676"/>
+        <location filename="../placesview.cpp" line="681"/>
         <source>Unmount</source>
         <translation>Ontkoppelen</translation>
     </message>
@@ -1363,7 +1363,12 @@ Wilt u ze in plaats daarvan permanent verwijderen?</translation>
         <translation>Uitwerpen</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="688"/>
+        <location filename="../placesview.cpp" line="658"/>
+        <source>Safely Remove</source>
+        <translation>Veilig verwijderen</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="693"/>
         <source>Show All Entries</source>
         <translation>Alle items tonen</translation>
     </message>
@@ -1483,7 +1488,7 @@ Gewijzigd: %2</translation>
     <message>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="674"/>
-        <location filename="../mountoperation.cpp" line="297"/>
+        <location filename="../mountoperation.cpp" line="315"/>
         <location filename="../utilities.cpp" line="154"/>
         <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
